package proxy.util;

import java.util.HashMap;
import java.util.Map;

public class HoverEvent {
	private final HoverEvent.Action action;
	private final ChatComponent value;

	public HoverEvent(HoverEvent.Action actionIn, ChatComponent valueIn) {
		this.action = actionIn;
		this.value = valueIn;
	}

	public HoverEvent.Action getAction() {
		return this.action;
	}

	public ChatComponent getValue() {
		return this.value;
	}

	public static enum Action {
		SHOW_TEXT("show_text", true),
		SHOW_ACHIEVEMENT("show_achievement", true),
		SHOW_ITEM("show_item", true),
		SHOW_ENTITY("show_entity", true);

		private static final Map<String, HoverEvent.Action> nameMapping = new HashMap();
		
		private final boolean allowedInChat;
		private final String canonicalName;

		private Action(String canonicalNameIn, boolean allowedInChatIn) {
			this.canonicalName = canonicalNameIn;
			this.allowedInChat = allowedInChatIn;
		}

		public boolean shouldAllowInChat() {
			return this.allowedInChat;
		}

		public String getCanonicalName() {
			return this.canonicalName;
		}

		public static HoverEvent.Action getValueByCanonicalName(String canonicalNameIn) {
			return nameMapping.get(canonicalNameIn);
		}

		static {
			for(HoverEvent.Action hoverevent$action : values()) {
				nameMapping.put(hoverevent$action.getCanonicalName(), hoverevent$action);
			}
		}
	}
}
